[Bf-blender-cvs] SVN commit: /data/svn/bf-blender [14995] branches/apricot/source/blender: svn merge -r14980:HEAD https://svn.blender.org/svnroot/bf-blender/trunk/ blender/

Campbell Barton ideasman42 at gmail.com
Tue May 27 11:22:59 CEST 2008


Revision: 14995
          http://projects.blender.org/plugins/scmsvn/viewcvs.php?view=rev&root=bf-blender&revision=14995
Author:   campbellbarton
Date:     2008-05-27 11:22:59 +0200 (Tue, 27 May 2008)

Log Message:
-----------
svn  merge  -r14980:HEAD https://svn.blender.org/svnroot/bf-blender/trunk/blender/
also removed some old transform snap stuff that isnt needed now.

Modified Paths:
--------------
    branches/apricot/source/blender/include/transform.h
    branches/apricot/source/blender/python/api2_2x/Particle.c
    branches/apricot/source/blender/src/poseobject.c
    branches/apricot/source/blender/src/toets.c
    branches/apricot/source/blender/src/transform_conversions.c
    branches/apricot/source/blender/src/transform_generics.c

Modified: branches/apricot/source/blender/include/transform.h
===================================================================
--- branches/apricot/source/blender/include/transform.h	2008-05-27 08:51:47 UTC (rev 14994)
+++ branches/apricot/source/blender/include/transform.h	2008-05-27 09:22:59 UTC (rev 14995)
@@ -31,7 +31,6 @@
 #define TRANSFORM_H
 
 #include "BIF_transform.h"
-#include "BIF_glutil.h" /* APRICOT HACK */
 
 /* ************************** Types ***************************** */
 
@@ -216,10 +215,6 @@
 	struct Object *poseobj;		/* if t->flag & T_POSE, this denotes pose object */
 	
 	void       *customData;		/* Per Transform custom data */
-	
-	/* APRICOT HACK */
-	void		*txdepth;
-	struct bglMats txmats;
 } TransInfo;
 
 

Modified: branches/apricot/source/blender/python/api2_2x/Particle.c
===================================================================
--- branches/apricot/source/blender/python/api2_2x/Particle.c	2008-05-27 08:51:47 UTC (rev 14994)
+++ branches/apricot/source/blender/python/api2_2x/Particle.c	2008-05-27 09:22:59 UTC (rev 14995)
@@ -828,7 +828,7 @@
 		/* little hack to calculate hair steps in render mode */
 		psys->renderdata = (void*)(int)1;
 
-		psys_cache_paths(ob, psys, cfra, 0);
+		psys_cache_paths(ob, psys, cfra, 1);
 
 		psys->renderdata = NULL;
 

Modified: branches/apricot/source/blender/src/poseobject.c
===================================================================
--- branches/apricot/source/blender/src/poseobject.c	2008-05-27 08:51:47 UTC (rev 14994)
+++ branches/apricot/source/blender/src/poseobject.c	2008-05-27 09:22:59 UTC (rev 14995)
@@ -659,6 +659,10 @@
 						free_constraints(&pchan->constraints);
 						copy_constraints(&pchan->constraints, &pchanact->constraints);
 						pchan->constflag = pchanact->constflag;
+						
+						if (ob->pose) {
+							ob->pose->flag |= POSE_RECALC;
+						}
 					}
 						break;
 					case 6: /* Transform Locks */
@@ -741,6 +745,10 @@
 		}
 		BLI_freelistN(&const_copy);
 		update_pose_constraint_flags(ob->pose); /* we could work out the flags but its simpler to do this */
+		
+		if (ob->pose) {
+			ob->pose->flag |= POSE_RECALC;
+		}
 	}
 	
 	DAG_object_flush_update(G.scene, ob, OB_RECALC_DATA);	// and all its relations

Modified: branches/apricot/source/blender/src/toets.c
===================================================================
--- branches/apricot/source/blender/src/transform_conversions.c	2008-05-27 08:51:47 UTC (rev 14994)
+++ branches/apricot/source/blender/src/transform_conversions.c	2008-05-27 09:22:59 UTC (rev 14995)
@@ -3611,11 +3611,6 @@
 	short redrawipo=0, resetslowpar=1;
 	int cancelled= (t->state == TRANS_CANCEL);
 	
-	/* APRICOT HACK */
-	if (t->txdepth) MEM_freeN(t->txdepth);
-	t->txdepth = NULL;
-	/* end... */
-	
 	if (t->spacetype==SPACE_VIEW3D) {
 		if (G.obedit) {
 			if (cancelled==0) {

Modified: branches/apricot/source/blender/src/transform_generics.c
===================================================================
--- branches/apricot/source/blender/src/transform_generics.c	2008-05-27 08:51:47 UTC (rev 14994)
+++ branches/apricot/source/blender/src/transform_generics.c	2008-05-27 09:22:59 UTC (rev 14995)
@@ -636,8 +636,6 @@
 
 void initTrans (TransInfo *t)
 {
-	t->txdepth = NULL;
-	
 	/* moving: is shown in drawobject() (transform color) */
 	if(G.obedit || (t->flag & T_POSE) ) G.moving= G_TRANSFORM_EDIT;
 	else if(G.f & G_PARTICLEEDIT) G.moving= G_TRANSFORM_PARTICLE;





More information about the Bf-blender-cvs mailing list
--- branches/apricot/source/blender/src/toets.c	2008-05-27 08:51:47 UTC (rev 14994)
+++ branches/apricot/source/blender/src/toets.c	2008-05-27 09:22:59 UTC (rev 14995)
@@ -228,8 +228,8 @@
 	}
 	else {
 		/* Indicate that this view is not inverted.
-		 * Don't do this for PADMINUS/PADPLUSKEY, though. (jobbe)*/
-		if (event != PADMINUS && event != PADPLUSKEY)
+		 * Don't do this for PADMINUS/PADPLUSKEY/PAD5, though. (jobbe)*/
+		if (! ELEM3(event, PADMINUS, PADPLUSKEY, PAD5) )
 			G.vd->flag2 &= ~V3D_OPP_DIRECTION_NAME;
 		
 

Modified: branches/apricot/source/blender/src/transform_conversions.c
===================================================================